@@ -30,8 +30,8 @@
 #include <gtk/gtksignal.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libgnome/libgnome.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <string.h>
 
 typedef struct
@@ -50,6 +50,8 @@ destroy_cb (GtkWidget *widget, ConfigPreview *preview)
 static void
 ext_changed_cb (MtmConfigGui *gui, MtmExt *ext, ConfigPreview *preview)
 {
+	gchar *file;
+	int len;
 	xmlDocPtr doc;
 	xmlNodePtr node;
 	gchar *xmlfile;
@@ -64,17 +66,30 @@ ext_changed_cb (MtmConfigGui *gui, MtmExt *ext, ConfigPreview *preview)
 	g_return_if_fail (MTM_IS_EXT (ext));
 	g_return_if_fail (preview != NULL);
 
+	g_print ("%s\n", ext->file);
+	file = ext->file;
+	if (!file)
+		return;
+
+	len = strlen (file);
+	if (file[len - 1] == '/')
+		file[len - 1] = '\0';
+	
 	/* Description label stuff */	
-	xmlfile = g_strconcat (ext->file, "/", g_basename (ext->file), ".xml", NULL);
+	xmlfile = g_strconcat (file, "/", g_basename (file), ".xml", NULL);
 	doc = xmlParseFile (xmlfile);
 	g_free (xmlfile);
 	if (!doc)
+	{
+		g_warning ("uh-oh!\n");
 		return;
+	}
 	
-	node = doc->root;
-	if (!(node && node->childs && !strcmp (node->name, "theme")))
+	node = doc->children;
+	if (!(node && node->children && !strcmp (node->name, "theme")))
 	{
 		xmlFreeDoc (doc);
+		g_warning ("invalid doc %s\n", node->name);
 		return;
 	}
 
@@ -87,7 +102,7 @@ ext_changed_cb (MtmConfigGui *gui, MtmExt *ext, ConfigPreview *preview)
 		desc = xmlGetProp (node, "_description");
 
 	labelstr = g_strdup_printf ("%s:\n%s",
-				    (name) ? name : g_basename (ext->file),
+				    (name) ? name : g_basename (file),
 				    (desc) ? desc : "");
 	gtk_label_set_text (GTK_LABEL (preview->label), labelstr);
 	
@@ -103,7 +118,7 @@ ext_changed_cb (MtmConfigGui *gui, MtmExt *ext, ConfigPreview *preview)
 
 	/* Preview image stuff */
 	imgfile = g_strconcat (ext->file, "/theme_preview.png", NULL);
-	imgbuf = gdk_pixbuf_new_from_file (imgfile);
+	imgbuf = gdk_pixbuf_new_from_file (imgfile, NULL);
 	g_free (imgfile);
 	if (!imgbuf)
 		return;
